pub enum SourceInfoSchema {
V1(SchemaVersion),
}Expand description
An enum tracking all available SRCINFO schemas.
The schema of a SRCINFO refers to the minimum required sections and keywords, as well as the complete set of available keywords in a specific version.
Variants
V1(SchemaVersion)
Schema for the SRCINFO file format.