Module error
alpm_
srcinfo
0.4.0
Module error
Module Items
Enums
In crate alpm_
srcinfo
alpm_srcinfo
Module
error
All error types that are exposed by this crate.
Enums

Error
The high-level error that can occur when using this crate.