#[non_exhaustive]pub enum Error {
AlpmType(Error),
Io(&'static str, Error),
IoPath(PathBuf, &'static str, Error),
InvalidUTF8(FromUtf8Error),
MissingSchemaSectionsOrKeywords {
sections: &'static str,
keywords: &'static str,
schema_version: &'static str,
},
NoInputFile,
ParseError(String),
SourceInfoErrors(SourceInfoErrors),
Json(Error),
UnsupportedSchemaVersion(String),
BridgeError(Error),
BridgeConversionError(BridgeError),
}Expand description
The high-level error that can occur when using this crate.
Notably, it contains two important enums in the context of parsing:
ParseErroris a already formatted error generated by thewinnowparser. This effectively means that some invalid data has been encountered.SourceInfoErrorsis a list of all logical or lint errors that’re encountered in the final step. This error also contains the original file on which the errors occurred.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AlpmType(Error)
ALPM type error
Io(&'static str, Error)
IO error
IoPath(PathBuf, &'static str, Error)
IO error with additional path info for more context.
InvalidUTF8(FromUtf8Error)
UTF-8 parse error when reading the input file.
MissingSchemaSectionsOrKeywords
A section or keyword is missing for a SRCINFO schema version.
Fields
NoInputFile
No input file given.
This error only occurs when running the crate::commands functions.
ParseError(String)
A parsing error that occurred during winnow file parsing.
SourceInfoErrors(SourceInfoErrors)
A list of errors that occurred during the final SRCINFO data parsing step.
These may contain any combination of SourceInfoError.
Json(Error)
JSON error while creating JSON formatted output.
This error only occurs when running the crate::commands functions.
UnsupportedSchemaVersion(String)
Unsupported schema version
BridgeError(Error)
A alpm-pkgbuild bridge error that occurred when converting a PKGBUILD to a SourceInfoV1
struct.
See PkgbuildError for further details.
BridgeConversionError(BridgeError)
A logical error occurred when transforming alpm-pkgbuild-bridge script output to a
SourceInfoV1 struct.
See BridgeError for further details.