pub struct SourceInfoErrors { /* private fields */ }Expand description
A helper struct to provide proper line based error/linting messages.
Provides a list of SourceInfoErrors and the SRCINFO data in which the errors occurred.
Implementations
Sourceimpl SourceInfoErrors
impl SourceInfoErrors
Sourcepub fn new(errors: Vec<SourceInfoError>, file_content: String) -> Self
pub fn new(errors: Vec<SourceInfoError>, file_content: String) -> Self
Creates a new SourceInfoErrors.
Sourcepub fn errors(&self) -> &Vec<SourceInfoError>
pub fn errors(&self) -> &Vec<SourceInfoError>
Returns a reference to the list of errors.
Sourcepub fn check_unrecoverable_errors(self) -> Result<(), Error>
pub fn check_unrecoverable_errors(self) -> Result<(), Error>
Filters for and errors on unrecoverable errors.
Consumes self and simply returns if self contains no SourceInfoError of type
SourceInfoErrorType::Unrecoverable.
Errors
Returns an error if self contains any SourceInfoError of type
SourceInfoErrorType::Unrecoverable.