pub enum ClearableProperty {
Show 13 variants
Description,
Url,
Licenses,
Changelog,
Install,
Groups,
Options,
Backups,
Dependencies(Option<Architecture>),
OptionalDependencies(Option<Architecture>),
Provides(Option<Architecture>),
Conflicts(Option<Architecture>),
Replaces(Option<Architecture>),
}Expand description
Properties used in pkgname sections that can be cleared.
Some variants of this enum are architecture-specific, as they might only be cleared for a specific architecture, but not for another.
Clearing a keyword in SRCINFO data is achieved by an empty keyword assignment, e.g.:
depends =Variants
Description
Url
Licenses
Changelog
Install
Groups
Options
Backups
Dependencies(Option<Architecture>)
OptionalDependencies(Option<Architecture>)
Provides(Option<Architecture>)
Conflicts(Option<Architecture>)
Replaces(Option<Architecture>)