pub enum RelationProperty {
Dependency(ArchProperty<RelationOrSoname>),
OptionalDependency(ArchProperty<OptionalDependency>),
Provides(ArchProperty<RelationOrSoname>),
Conflicts(ArchProperty<PackageRelation>),
Replaces(ArchProperty<PackageRelation>),
}Expand description
Properties related to package relations.
This only handles the shared package relations that can be used in both pkgbase and pkgname
sections.
pkgbase specific relations are explicitly handled in the RawPackageBase enum.
See [alpm-package-relation] for further details on package relations and [alpm-sonamev1] for
information on soname handling.
[alpm-package-relation]: https://alpm.archlinux.page/specifications/alpm-package-relation.7.html
[alpm-sonamev1]: https://alpm.archlinux.page/specifications/alpm-sonamev1.7.html
Variants
Dependency(ArchProperty<RelationOrSoname>)
OptionalDependency(ArchProperty<OptionalDependency>)
Provides(ArchProperty<RelationOrSoname>)
Conflicts(ArchProperty<PackageRelation>)
Replaces(ArchProperty<PackageRelation>)
Implementations
Sourceimpl RelationProperty
impl RelationProperty
pub fn architecture(&self) -> Option<Architecture>