Enum SourceProperty

pub enum SourceProperty {
    Source(ArchProperty<Source>),
    NoExtract(ArchProperty<String>),
    B2Checksum(ArchProperty<SkippableChecksum<Blake2b512>>),
    Md5Checksum(ArchProperty<SkippableChecksum<Md5>>),
    Sha1Checksum(ArchProperty<SkippableChecksum<Sha1>>),
    Sha256Checksum(ArchProperty<SkippableChecksum<Sha256>>),
    Sha224Checksum(ArchProperty<SkippableChecksum<Sha224>>),
    Sha384Checksum(ArchProperty<SkippableChecksum<Sha384>>),
    Sha512Checksum(ArchProperty<SkippableChecksum<Sha512>>),
}
Properties related to package sources.

Sources and related properties can be architecture specific.

The source, noextract and checksum related keywords in SRCINFO data correlate in ordering: noextract and any checksum entries are ordered in the same way as the respective source entry they relate to. The representation of this correlation is normalized after initial parsing.

Variants