pub enum ClearableProperty {
Show 13 variants
Description,
Url,
Licenses,
Changelog,
Install,
Groups,
Options,
Backups,
Dependencies(Option<Architecture>),
OptionalDependencies(Option<Architecture>),
Provides(Option<Architecture>),
Conflicts(Option<Architecture>),
Replaces(Option<Architecture>),
}Expand description
Properties used in pkgname sections that can be cleared.
Some variants of this enum are architecture-specific, as they might only be cleared for a specific architecture, but not for another.
Clearing a keyword in SRCINFO data is achieved by an empty keyword assignment, e.g.:
depends =Variants
Description
The description for a package.
Url
The upstream URL for a package.
Licenses
The licenses that apply to a package.
Changelog
The changelog for a package.
Install
The alpm-install-scriptlet for a package.
Groups
The alpm-package-groups a package is part of.
Options
The build tool options used for building a package.
Backups
The path to a file in a package that should be backed up.
Dependencies(Option<Architecture>)
The alpm-architecture of run-time dependencies.
OptionalDependencies(Option<Architecture>)
The alpm-architecture of optional dependencies.
Provides(Option<Architecture>)
The alpm-architecture of provisions.
Conflicts(Option<Architecture>)
The alpm-architecture of conflicts.
Replaces(Option<Architecture>)
The alpm-architecture of replacements.