PackageBaseProperty

Enum PackageBaseProperty 

pub enum PackageBaseProperty {
    EmptyLine,
    Comment(String),
    MetaProperty(SharedMetaProperty),
    PackageVersion(PackageVersion),
    PackageRelease(PackageRelease),
    PackageEpoch(Epoch),
    ValidPgpKeys(OpenPGPIdentifier),
    RelationProperty(RelationProperty),
    CheckDependency(ArchProperty<PackageRelation>),
    MakeDependency(ArchProperty<PackageRelation>),
    SourceProperty(SourceProperty),
}
All possible properties of a pkgbase section in SRCINFO data.

The ordering of the variants represents the order in which keywords would appear in a SRCINFO file. This is important as the file format represents stateful data which needs normalization.

The SRCINFO format allows comments and empty lines anywhere in the file. To produce meaningful error messages for the consumer during data normalization, the line number on which an error occurred is encoded in the parsed data.

Variants



EmptyLine

An empty line.



Comment(String)

A commented line.



MetaProperty(SharedMetaProperty)



PackageVersion(PackageVersion)



PackageRelease(PackageRelease)



PackageEpoch(Epoch)

An Epoch.



ValidPgpKeys(OpenPGPIdentifier)



RelationProperty(RelationProperty)



CheckDependency(ArchProperty<PackageRelation>)

Build-time specific check dependencies.



MakeDependency(ArchProperty<PackageRelation>)

Build-time specific make dependencies.



SourceProperty(SourceProperty)

Source file properties