pub enum PackageProperty {
EmptyLine,
Comment(String),
MetaProperty(SharedMetaProperty),
RelationProperty(RelationProperty),
Clear(ClearableProperty),
}Expand description
All possible properties of a pkgname section in SRCINFO data.
It’s very similar to RawPackageBase, but with less fields and the possibility to explicitly
set some fields to “empty”.
Variants
EmptyLine
An empty line.
Comment(String)
A commented line.
MetaProperty(SharedMetaProperty)
RelationProperty(RelationProperty)
Clear(ClearableProperty)