pub enum SourceProperty {
Source(ArchProperty<Source>),
NoExtract(String),
B2Checksum(ArchProperty<SkippableChecksum<Blake2b512>>),
Md5Checksum(ArchProperty<SkippableChecksum<Md5>>),
Sha1Checksum(ArchProperty<SkippableChecksum<Sha1>>),
Sha256Checksum(ArchProperty<SkippableChecksum<Sha256>>),
Sha224Checksum(ArchProperty<SkippableChecksum<Sha224>>),
Sha384Checksum(ArchProperty<SkippableChecksum<Sha384>>),
Sha512Checksum(ArchProperty<SkippableChecksum<Sha512>>),
CrcChecksum(ArchProperty<SkippableChecksum<Crc32Cksum>>),
}Expand description
Properties related to package sources.
Sources and related properties can be architecture specific.
The source, noextract and checksum related keywords in SRCINFO data correlate in ordering:
noextract and any checksum entries are ordered in the same way as the respective source
entry they relate to. The representation of this correlation is normalized after initial
parsing.
Variants
Source(ArchProperty<Source>)
An ArchProperty<Source> for a source entry.
NoExtract(String)
An ArchProperty<String> for a noextract entry.
B2Checksum(ArchProperty<SkippableChecksum<Blake2b512>>)
An ArchProperty<SkippableChecksum<Blake2b512>> for a blake2 hash digest.
Md5Checksum(ArchProperty<SkippableChecksum<Md5>>)
An ArchProperty<SkippableChecksum<Md5>> for an MD-5 hash digest.
Sha1Checksum(ArchProperty<SkippableChecksum<Sha1>>)
An ArchProperty<SkippableChecksum<Sha1>> for a SHA-1 hash digest.
Sha256Checksum(ArchProperty<SkippableChecksum<Sha256>>)
An ArchProperty<SkippableChecksum<Sha256>> for a SHA-256 hash digest.
Sha224Checksum(ArchProperty<SkippableChecksum<Sha224>>)
An ArchProperty<SkippableChecksum<Sha224>> for a SHA-224 hash digest.
Sha384Checksum(ArchProperty<SkippableChecksum<Sha384>>)
An ArchProperty<SkippableChecksum<Sha384>> for a SHA-384 hash digest.
Sha512Checksum(ArchProperty<SkippableChecksum<Sha512>>)
An ArchProperty<SkippableChecksum<Sha512>> for a SHA-512 hash digest.
CrcChecksum(ArchProperty<SkippableChecksum<Crc32Cksum>>)
An ArchProperty<SkippableChecksum<Crc32Cksum>> for a CRC-32/CKSUM hash digest.