All error types that are exposed by this crate.
Structs
- Source
Info Error - Errors that may occur when converting
SourceInfoContentinto aSourceInfoV1. - Source
Info Errors - A helper struct to provide proper line based error/linting messages.
Enums
- Error
- The high-level error that can occur when using this crate.
- Source
Info Error Type - A
SourceInfoErrortype.
Functions
- deprecation
- Creates a
SourceInfoErrorfor deprecation warnings. - lint
- Creates a
SourceInfoErrorfor linting issues. - unrecoverable
- Creates a
SourceInfoErrorfor unrecoverable issues.