pub enum BridgeError {
NoName,
InvalidPackageName {
name: String,
error: Error,
},
UndeclaredPackageName(String),
UnusedPackageFunction(Name),
MissingRequiredKeyword {
keyword: Keyword,
},
ParseError {
keyword: Keyword,
error: String,
},
WrongVariableType {
keyword: String,
expected: String,
actual: String,
},
UnexpectedArchitecture {
keyword: Keyword,
suffix: Architecture,
},
UnclearableValue {
keyword: Keyword,
},
UnexpectedArray {
keyword: Keyword,
values: Vec<String>,
},
DuplicateArchitecture {
duplicate: Architecture,
},
}Expand description
A lower-level error that may occur when converting alpm-pkgbuild-bridge script output into the
SourceInfo format.
Variants
NoName
No pkgname has been specified.
InvalidPackageName
A package name is not valid.
UndeclaredPackageName(String)
A package function has been declared for a split package, but it is not defined in
pkgname.
UnusedPackageFunction(Name)
An unused package function exists for an undeclared alpm-split-package.
MissingRequiredKeyword
A type parser fails on a certain keyword.
ParseError
A type parser fails on a certain keyword.
WrongVariableType
A variable is expected to be of a different type.
E.g. String when an Array is expected.
Fields
UnexpectedArchitecture
A keyword has an architecture suffix even though it shouldn’t have one.
Fields
suffix: ArchitectureThe architecture that is found for the keyword.
UnclearableValue
A keyword that cannot be cleared is attempted to be cleared.
UnexpectedArray
A keyword should have only a single value, but an array is found.
Fields
DuplicateArchitecture
A duplicate Architecture is specified.
Fields
duplicate: ArchitectureThe duplicate architecture.